package cn.com.infosec.asn1;

import cn.com.infosec.util.Arrays;
import java.io.IOException;

public class DERApplicationSpecific extends ASN1Object {
   private final boolean isConstructed;
   private final int tag;
   private final byte[] octets;

   DERApplicationSpecific(boolean isConstructed, int tag, byte[] octets) {
      this.isConstructed = isConstructed;
      this.tag = tag;
      this.octets = octets;
   }

   public DERApplicationSpecific(int tag, byte[] octets) {
      this(false, tag, octets);
   }

   public DERApplicationSpecific(int tag, DEREncodable object) {
      this(true, tag, object);
   }

   public DERApplicationSpecific(boolean explicit, int tag, DEREncodable object) {
      if (tag < 31) {
         boolean var10000 = explicit;
         boolean var10004 = explicit;
         byte[] explicit1 = object.getDERObject().getDEREncoded();
         this.isConstructed = var10004;
         this.tag = tag;
         if (var10000) {
            this.octets = explicit1;
         } else {
            DERApplicationSpecific var6 = this;
            int var10002 = this.getLengthOfLength(explicit1);
            int var4;
            System.arraycopy(explicit1, var10002, explicit1 = new byte[var4 = explicit1.length - var10002], 0, var4);
            var6.octets = explicit1;
         }

      } else {
         throw new IOException("unsupported tag number");
      }
   }

   private int getLengthOfLength(byte[] data) {
      int var2;
      for(var2 = 2; (data[var2 - 1] & 128) != 0; ++var2) {
      }

      return var2;
   }

   public boolean isConstructed() {
      return this.isConstructed;
   }

   public byte[] getContents() {
      return this.octets;
   }

   public int getApplicationTag() {
      return this.tag;
   }

   public DERObject getObject() {
      return (new ASN1InputStream(this.getContents())).readObject();
   }

   public DERObject getObject(int derTagNo) {
      if (this.tag < 31) {
         byte[] var2;
         (var2 = this.getEncoded())[0] = (byte)derTagNo;
         return (new ASN1InputStream(var2)).readObject();
      } else {
         throw new IOException("unsupported tag number");
      }
   }

   void encode(DEROutputStream out) {
      byte var2 = 64;
      if (this.isConstructed) {
         var2 = 96;
      }

      DERApplicationSpecific var10001;
      int var3;
      int var4;
      if ((var3 = this.tag) < 31) {
         var10001 = this;
         var4 = var2 | var3;
         out.writeEncoded(var4, var10001.octets);
      } else {
         DEROutputStream var10000 = out;
         var10001 = this;
         var4 = var2 | 31;
         byte[] out1 = var10001.octets;
         var10000.writeEncodedHigh(var4, var3, out1);
      }

   }

   boolean asn1Equals(DERObject o) {
      if (!(o instanceof DERApplicationSpecific)) {
         return false;
      } else {
         DERApplicationSpecific o1 = (DERApplicationSpecific)o;
         return this.isConstructed == o1.isConstructed && this.tag == o1.tag && Arrays.areEqual(this.octets, o1.octets);
      }
   }

   public int hashCode() {
      return this.isConstructed ^ this.tag ^ Arrays.hashCode(this.octets);
   }
}
